@@ -6,10 +6,7 @@
 #' Estimates the standard deviations of the nugget term in standard GP by
 #' calculating the standard deviations of the residuals.
 #'
-#' @param data A data.frame of observation data.
-#'   - Column 1: Outcome (Y)
-#'   - Column 2: Exposure or treatment (w)
-#'   - Column 3~m: Confounders (C)
+#' @param data A vector of outcome data.
 #' @param sigma_obs Covariance matrix between observed covariates.
 #' @param inv_sigma_obs Inverse of the covariance matrix between observed
 #' covariates.
@@ -21,8 +18,8 @@
 #'
 estimate_noise_gp <- function(data, sigma_obs, inv_sigma_obs) {
 
-  noise <- sd(data$Y - arma_mm(sigma_obs - diag(nrow(sigma_obs)),
-                               arma_mm(inv_sigma_obs, data$Y)))
+  noise <- sd(data - arma_mm(sigma_obs - diag(nrow(sigma_obs)),
+                               arma_mm(inv_sigma_obs, data)))
 
   return(noise)
 }
